==> tool-sql-2.6.0-pre-sources.jar: io/ciera/tool/sql/ooaofooa/body/Body.java <==
package io.ciera.tool.sql.ooaofooa.body;


import io.ciera.runtime.summit.classes.IModelInstance;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.Sql;
import io.ciera.tool.sql.architecture.invocable.InvocableObject;
import io.ciera.tool.sql.architecture.invocable.InvocableObjectSet;
import io.ciera.tool.sql.ooaofooa.body.Block;
import io.ciera.tool.sql.ooaofooa.body.BlockSet;
import io.ciera.tool.sql.ooaofooa.body.BodyInComponent;
import io.ciera.tool.sql.ooaofooa.body.BodyInElement;
import io.ciera.tool.sql.ooaofooa.body.BridgeBody;
import io.ciera.tool.sql.ooaofooa.body.DerivedAttributeBody;
import io.ciera.tool.sql.ooaofooa.body.FunctionBody;
import io.ciera.tool.sql.ooaofooa.body.OperationBody;
import io.ciera.tool.sql.ooaofooa.body.ProvidedOperationBody;
import io.ciera.tool.sql.ooaofooa.body.ProvidedSignalBody;
import io.ciera.tool.sql.ooaofooa.body.RequiredOperationBody;
import io.ciera.tool.sql.ooaofooa.body.RequiredSignalBody;
import io.ciera.tool.sql.ooaofooa.body.StateActionBody;
import io.ciera.tool.sql.ooaofooa.body.TransitionActionBody;

import ooaofooa.datatypes.Instance;


public interface Body extends IModelInstance<Body,Sql> {

    // attributes
    public UniqueId getAction_ID() throws XtumlException;
    public void setAction_ID( UniqueId m_Action_ID ) throws XtumlException;
    public String getType() throws XtumlException;
    public void setType( String m_Type ) throws XtumlException;
    public int getLoopLevel() throws XtumlException;
    public void setLoopLevel( int m_LoopLevel ) throws XtumlException;
    public UniqueId getBlock_ID() throws XtumlException;
    public void setBlock_ID( UniqueId ref_Block_ID ) throws XtumlException;
    public void setCurrentScope_ID( UniqueId ref_CurrentScope_ID ) throws XtumlException;
    public UniqueId getCurrentScope_ID() throws XtumlException;
    public Instance getReturn_value() throws XtumlException;
    public void setReturn_value( Instance m_return_value ) throws XtumlException;
    public void setLabel( String m_Label ) throws XtumlException;
    public String getLabel() throws XtumlException;
    public void setParsed_Block_ID( UniqueId ref_Parsed_Block_ID ) throws XtumlException;
    public UniqueId getParsed_Block_ID() throws XtumlException;
    public void setReturnFound( boolean m_ReturnFound ) throws XtumlException;
    public boolean getReturnFound() throws XtumlException;


    // operations


    // selections
    default public void addR432_actions_transformed_from_InvocableObject( InvocableObject inst ) {}
    default public void removeR432_actions_transformed_from_InvocableObject( InvocableObject inst ) {}
    public InvocableObjectSet R432_actions_transformed_from_InvocableObject() throws XtumlException;
    default public void addR601_has_committed_Block( Block inst ) {}
    default public void removeR601_has_committed_Block( Block inst ) {}
    public BlockSet R601_has_committed_Block() throws XtumlException;
    default public void addR612_has_parsed_Block( Block inst ) {}
    default public void removeR612_has_parsed_Block( Block inst ) {}
    public BlockSet R612_has_parsed_Block() throws XtumlException;
    default public void setR640_is_declared_in_BodyInElement( BodyInElement inst ) {}
    public BodyInElement R640_is_declared_in_BodyInElement() throws XtumlException;
    default public void setR650_has_parsed_outer_Block( Block inst ) {}
    public Block R650_has_parsed_outer_Block() throws XtumlException;
    default public void setR666_has_committed_outer_Block( Block inst ) {}
    public Block R666_has_committed_outer_Block() throws XtumlException;
    default public void setR694_is_declared_in_BodyInComponent( BodyInComponent inst ) {}
    public BodyInComponent R694_is_declared_in_BodyInComponent() throws XtumlException;
    default public void setR698_is_a_BridgeBody( BridgeBody inst ) {}
    public BridgeBody R698_is_a_BridgeBody() throws XtumlException;
    default public void setR698_is_a_DerivedAttributeBody( DerivedAttributeBody inst ) {}
    public DerivedAttributeBody R698_is_a_DerivedAttributeBody() throws XtumlException;
    default public void setR698_is_a_FunctionBody( FunctionBody inst ) {}
    public FunctionBody R698_is_a_FunctionBody() throws XtumlException;
    default public void setR698_is_a_OperationBody( OperationBody inst ) {}
    public OperationBody R698_is_a_OperationBody() throws XtumlException;
    default public void setR698_is_a_ProvidedOperationBody( ProvidedOperationBody inst ) {}
    public ProvidedOperationBody R698_is_a_ProvidedOperationBody() throws XtumlException;
    default public void setR698_is_a_ProvidedSignalBody( ProvidedSignalBody inst ) {}
    public ProvidedSignalBody R698_is_a_ProvidedSignalBody() throws XtumlException;
    default public void setR698_is_a_RequiredOperationBody( RequiredOperationBody inst ) {}
    public RequiredOperationBody R698_is_a_RequiredOperationBody() throws XtumlException;
    default public void setR698_is_a_RequiredSignalBody( RequiredSignalBody inst ) {}
    public RequiredSignalBody R698_is_a_RequiredSignalBody() throws XtumlException;
    default public void setR698_is_a_StateActionBody( StateActionBody inst ) {}
    public StateActionBody R698_is_a_StateActionBody() throws XtumlException;
    default public void setR698_is_a_TransitionActionBody( TransitionActionBody inst ) {}
    public TransitionActionBody R698_is_a_TransitionActionBody() throws XtumlException;
    default public void setR699_has_current_scope_Block( Block inst ) {}
    public Block R699_has_current_scope_Block() throws XtumlException;


}

==> tool-sql-2.7.0-sources.jar: io/ciera/tool/sql/ooaofooa/body/Body.java <==
package io.ciera.tool.sql.ooaofooa.body;


import io.ciera.runtime.summit.classes.IModelInstance;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.Sql;
import io.ciera.tool.sql.architecture.invocable.InvocableObject;
import io.ciera.tool.sql.ooaofooa.body.Block;
import io.ciera.tool.sql.ooaofooa.body.BlockSet;
import io.ciera.tool.sql.ooaofooa.body.BodyInComponent;
import io.ciera.tool.sql.ooaofooa.body.BodyInElement;
import io.ciera.tool.sql.ooaofooa.body.BridgeBody;
import io.ciera.tool.sql.ooaofooa.body.DerivedAttributeBody;
import io.ciera.tool.sql.ooaofooa.body.FunctionBody;
import io.ciera.tool.sql.ooaofooa.body.OperationBody;
import io.ciera.tool.sql.ooaofooa.body.ProvidedOperationBody;
import io.ciera.tool.sql.ooaofooa.body.ProvidedSignalBody;
import io.ciera.tool.sql.ooaofooa.body.RequiredOperationBody;
import io.ciera.tool.sql.ooaofooa.body.RequiredSignalBody;
import io.ciera.tool.sql.ooaofooa.body.StateActionBody;
import io.ciera.tool.sql.ooaofooa.body.TransitionActionBody;

import ooaofooa.datatypes.Instance;


public interface Body extends IModelInstance<Body,Sql> {

    // attributes
    public UniqueId getAction_ID() throws XtumlException;
    public void setAction_ID( UniqueId m_Action_ID ) throws XtumlException;
    public String getType() throws XtumlException;
    public void setType( String m_Type ) throws XtumlException;
    public void setLoopLevel( int m_LoopLevel ) throws XtumlException;
    public int getLoopLevel() throws XtumlException;
    public UniqueId getBlock_ID() throws XtumlException;
    public void setBlock_ID( UniqueId ref_Block_ID ) throws XtumlException;
    public UniqueId getCurrentScope_ID() throws XtumlException;
    public void setCurrentScope_ID( UniqueId ref_CurrentScope_ID ) throws XtumlException;
    public void setReturn_value( Instance m_return_value ) throws XtumlException;
    public Instance getReturn_value() throws XtumlException;
    public void setLabel( String m_Label ) throws XtumlException;
    public String getLabel() throws XtumlException;
    public void setParsed_Block_ID( UniqueId ref_Parsed_Block_ID ) throws XtumlException;
    public UniqueId getParsed_Block_ID() throws XtumlException;
    public void setReturnFound( boolean m_ReturnFound ) throws XtumlException;
    public boolean getReturnFound() throws XtumlException;


    // operations


    // selections
    default public void setR432_InvocableObject( InvocableObject inst ) {}
    public InvocableObject R432_InvocableObject() throws XtumlException;
    default public void addR601_has_committed_Block( Block inst ) {}
    default public void removeR601_has_committed_Block( Block inst ) {}
    public BlockSet R601_has_committed_Block() throws XtumlException;
    default public void addR612_has_parsed_Block( Block inst ) {}
    default public void removeR612_has_parsed_Block( Block inst ) {}
    public BlockSet R612_has_parsed_Block() throws XtumlException;
    default public void setR640_is_declared_in_BodyInElement( BodyInElement inst ) {}
    public BodyInElement R640_is_declared_in_BodyInElement() throws XtumlException;
    default public void setR650_has_parsed_outer_Block( Block inst ) {}
    public Block R650_has_parsed_outer_Block() throws XtumlException;
    default public void setR666_has_committed_outer_Block( Block inst ) {}
    public Block R666_has_committed_outer_Block() throws XtumlException;
    default public void setR694_is_declared_in_BodyInComponent( BodyInComponent inst ) {}
    public BodyInComponent R694_is_declared_in_BodyInComponent() throws XtumlException;
    default public void setR698_is_a_BridgeBody( BridgeBody inst ) {}
    public BridgeBody R698_is_a_BridgeBody() throws XtumlException;
    default public void setR698_is_a_DerivedAttributeBody( DerivedAttributeBody inst ) {}
    public DerivedAttributeBody R698_is_a_DerivedAttributeBody() throws XtumlException;
    default public void setR698_is_a_FunctionBody( FunctionBody inst ) {}
    public FunctionBody R698_is_a_FunctionBody() throws XtumlException;
    default public void setR698_is_a_OperationBody( OperationBody inst ) {}
    public OperationBody R698_is_a_OperationBody() throws XtumlException;
    default public void setR698_is_a_ProvidedOperationBody( ProvidedOperationBody inst ) {}
    public ProvidedOperationBody R698_is_a_ProvidedOperationBody() throws XtumlException;
    default public void setR698_is_a_ProvidedSignalBody( ProvidedSignalBody inst ) {}
    public ProvidedSignalBody R698_is_a_ProvidedSignalBody() throws XtumlException;
    default public void setR698_is_a_RequiredOperationBody( RequiredOperationBody inst ) {}
    public RequiredOperationBody R698_is_a_RequiredOperationBody() throws XtumlException;
    default public void setR698_is_a_RequiredSignalBody( RequiredSignalBody inst ) {}
    public RequiredSignalBody R698_is_a_RequiredSignalBody() throws XtumlException;
    default public void setR698_is_a_StateActionBody( StateActionBody inst ) {}
    public StateActionBody R698_is_a_StateActionBody() throws XtumlException;
    default public void setR698_is_a_TransitionActionBody( TransitionActionBody inst ) {}
    public TransitionActionBody R698_is_a_TransitionActionBody() throws XtumlException;
    default public void setR699_has_current_scope_Block( Block inst ) {}
    public Block R699_has_current_scope_Block() throws XtumlException;


}
